api.datastores.v1 package — Argus-Toolbelt 1.0 documentation

# api.datastores.v1 package

## Subpackages

- api.datastores.v1.store package
  - Submodules
  - api.datastores.v1.store.store module
  - Module contents

## Submodules

## api.datastores.v1.descriptor module

Autogenerated API

`api.datastores.v1.descriptor.` `add_data_store_descriptor`(name: str = None, description: str = None, lifeTime: int = None, behaviourType: str = 'CENTRAL', dataType: str = 'MAP (key/value store)', globalData: bool = 'False', expireData: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Adds a new datastore descriptor. (PUBLIC)

  Return type: | `dict`
  Parameters: | name (str) – Name for new datastore. Name must be unique. => [a-zA-Z0-9_-.]* description (str) – Description of the datastore. => [sw{}$-().[]“‘_/,*+#:@!?;]* lifeTime (int) – The requested expiry time in milliseconds. Requires a positive value (if expireData is true). behaviourType (str) – Datastore behaviour. CENTRAL stores are only updated centrally, but may be used in distributed processing. LOCAL and DISTRIBUTED stores are not stored centrally, but updated in the distributed system. DISTRIBUTED may be shared between processing nodes. (default CENTRAL) dataType (str) – Select data type: list of values or key/value store. (default MAP (key/value store)) globalData (bool) – If true, datastore only accepts global data (not customer bound). expireData (bool) – If true, datastore entries will expire after the configured time period since added/last updated.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 482, “limit”: 357, “responseCode”: 200, “count”: 921, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Close culture home according.”, “messageTemplate”: “Hear center then source want.”, “field”: “City skin window center end.”, “parameter”: {}, “timestamp”: 1002236195}], “currentPage”: 287, “size”: 102}

`api.datastores.v1.descriptor.` `delete_data_store_descriptor`(dataStore: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Deletes an existing datastore descriptor. (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 581, “limit”: 434, “responseCode”: 200, “count”: 982, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Serious seven century teacher school national present population.”, “messageTemplate”: “Debate floor above material treatment by military.”, “field”: “Argue this drug represent husband painting either.”, “parameter”: {}, “timestamp”: 1073414695}], “currentPage”: 669, “size”: 472}

`api.datastores.v1.descriptor.` `get_descriptor`(dataStore: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a Datastore descriptor identified by its name. (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Descriptor name
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 110, “limit”: 540, “responseCode”: 200, “count”: 166, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Church firm thus.”, “messageTemplate”: “Seven that school painting once kind mind.”, “field”: “Garden deal price music street door.”, “parameter”: {}, “timestamp”: 514452691}], “currentPage”: 692, “size”: 453}

`api.datastores.v1.descriptor.` `search_descriptors`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, keywords: list = None, keywordFieldStrategy: list = None, keywordMatchStrategy: str = None, sortBy: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns an array of DataStore descriptors matching search criteria (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – keywords (list) – Search for datastores matching keyword keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 633, “limit”: 65, “responseCode”: 200, “count”: 811, “data”: [{“name”: “Theresa Wood”, “description”: “Than data whose half across business.”, “dataType”: “MAP”, “behaviourType”: “CENTRAL”, “lastUpdatedTimestamp”: 220442774, “lastUpdatedByUser”: {“id”: 29, “customerID”: 506, “userName”: “xward”, “name”: “Benjamin Smith”}, “lifeTime”: 629, “deleted”: true, “globalData”: true, “expireData”: false}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Hospital manage final relationship beautiful friend.”, “messageTemplate”: “Present big scene along.”, “field”: “Radio result probably material which.”, “parameter”: {}, “timestamp”: 737984016}], “currentPage”: 681, “size”: 447}

`api.datastores.v1.descriptor.` `search_descriptors_simple`(keywords: list = None, keywordField: list = None, sortBy: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns an array of DataStore descriptors matching search parameters (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search sortBy (list) – Sort search result offset (int) – Skip a number of results limit (int) – Maximum number of returned results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 920, “limit”: 168, “responseCode”: 200, “count”: 834, “data”: [{“name”: “Jillian Holden”, “description”: “Parent huge guy sound develop real name study.”, “dataType”: “MAP”, “behaviourType”: “DISTRIBUTED”, “lastUpdatedTimestamp”: 920368384, “lastUpdatedByUser”: {“id”: 681, “customerID”: 101, “userName”: “johnrobertson”, “name”: “Katherine Adams”}, “lifeTime”: 6, “deleted”: true, “globalData”: true, “expireData”: true}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “He opportunity dinner fall know surface.”, “messageTemplate”: “Tonight want he.”, “field”: “Change until these machine.”, “parameter”: {}, “timestamp”: 975339593}], “currentPage”: 720, “size”: 335}

`api.datastores.v1.descriptor.` `update_data_store_descriptor`(dataStore: str, name: str = None, description: str = None, lifeTime: int = None, globalData: bool = 'False', expireData: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Updates an existing datastore descriptor. (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name name (str) – If set, request datastore to change name. All entries will be updated (so may take long time for large stores). => [a-zA-Z0-9_-.]* description (str) – If set, update description on datastore. => [sw{}$-().[]“‘_/,*+#:@!?;]* lifeTime (int) – If set (to positive value), change the expiry time for this datastore. Requires that the store has enabled expireData. Default is no change. globalData (bool) – If set, change the global data flag on this datastore. Default is no change. expireData (bool) – If set, change the expire data flag on this datastore. Default is no change.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 205, “limit”: 923, “responseCode”: 200, “count”: 853, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Save foot leave room wife fine national.”, “messageTemplate”: “Toward program bit expect miss.”, “field”: “Purpose much beat must hold ok day.”, “parameter”: {}, “timestamp”: 720500521}], “currentPage”: 163, “size”: 704}

## Module contents